summaryrefslogtreecommitdiff
path: root/addons/base_dashboard/static/src/xml/base_dashboard.xml
diff options
context:
space:
mode:
authorXavier Morel <xmo@openerp.com>2011-06-21 11:18:36 +0200
committerXavier Morel <xmo@openerp.com>2011-06-21 11:18:36 +0200
commit7d9263a85c426e043abbc06cb3b80e935e811dea (patch)
tree55ca3cd7a365d72b97e197dfbfd9ee7ab7b06d33 /addons/base_dashboard/static/src/xml/base_dashboard.xml
parent6371d8f8402fa0acb88f35e53d98038ab16de1d9 (diff)
[IMP] converting values to strings with (new String) is 10~20% slower than using just String(). Switch Qweb.html_escape to String()
bzr revid: xmo@openerp.com-20110621091836-5cnjwac3m3n12380
Diffstat (limited to 'addons/base_dashboard/static/src/xml/base_dashboard.xml')
0 files changed, 0 insertions, 0 deletions